@@ -109,3 +109,70 @@ test.Language.inputoperator <- function(){
 	checkEquals( funx(), call("rnorm", 10L, sd = 10L ) , msg = "Language<<" )
 }
 
+test.Language.unary.call <- function(){
+	
+	funx <- cfunction(signature(y = "integer" ), '
+	
+	Language call( "seq", Named("from", 10 ), Named("to", 0 ) ) ;
+	IntegerVector x(y) ;
+	List output( x.size() ) ;
+	std::transform( 
+		x.begin(), x.end(), 
+		output.begin(),
+		unary_call<int>(call)
+		) ;
+	return output ;
+	', Rcpp = TRUE, verbose = FALSE, includes = "using namespace Rcpp;" )
+	
+	checkEquals( 
+		funx( 1:10 ), 
+		lapply( 1:10, function(n) seq(from=n, to = 0 ) ), 
+		msg = "c++ lapply using calls" )
+	
+}
+
+test.Language.unary.call.index <- function(){
+	
+	funx <- cfunction(signature(y = "integer" ), '
+	Language call( "seq", 10, 0 ) ;
+	IntegerVector x(y) ;
+	List output( x.size() ) ;
+	std::transform( 
+		x.begin(), x.end(), 
+		output.begin(),
+		unary_call<int>(call,2)
+		) ;
+	return output ;
+	', Rcpp = TRUE, verbose = FALSE, includes = "using namespace Rcpp;" )
+	
+	checkEquals( 
+		funx( 1:10 ), 
+		lapply( 1:10, function(n) seq(from=n, to = 0 ) ), 
+		msg = "c++ lapply using calls" )
+	
+}
+
+test.Language.binary.call <- function(){
+	
+	funx <- cfunction(signature(y1 = "integer", y2 = "integer" ), '
+	
+	Language call( "seq", Named("from", 10 ), Named("to", 0 ) ) ;
+	IntegerVector x1(y1) ;
+	IntegerVector x2(y2) ;
+	List output( x1.size() ) ;
+	std::transform( 
+		x1.begin(), x1.end(), x2.begin(),
+		output.begin(),
+		binary_call<int,int>(call)
+		) ;
+	return output ;
+	', Rcpp = TRUE, verbose = FALSE, includes = "using namespace Rcpp;" )
+	
+	checkEquals( 
+		funx( 1:10, 11:20 ), 
+		lapply( 1:10, function(n) seq(n, n+10) ), 
+		msg = "c++ lapply using calls" )
+	
+}
+
+
